@@ -9,5 +9,5 @@ utils::globalVariables(
       "yhat", ".model_desc_new", ".model_desc_old", ".model_desc_user",
       ".model_table", ".model_table_clean", ".residuals", ".is_null", ".",
       ".final_values", ".idx_values", ".pred_values", ".row_id", "..row_id", "rowid..",
-      "id", ".id")
+      "id", ".id", "this_model")
 )
